==> inkribbon-6.x-5.13.tar.gz: inkribbon/template.php <==
<?php
// $Id: template.php,v 1.38.2.3.2.3.2.23 2010/06/07 13:20:19 mverbaar Exp $

/**
 * Process variables for block.tpl.php.
 */
function inkribbon_preprocess_block(&$vars) {
  // Provide useful classes.
  $vars['classes'] = 'block block-' . $vars['block']->module;
}

/**
 * Process variables for comment.tpl.php.
 */
function inkribbon_preprocess_comment(&$vars) {
  // Provide useful classes.
  $classes = array(
    'comment',
    $status,
  );
  if ($vars['comment']->new) {
    $classes[] = 'comment-new';
  }
  $vars['classes'] = join(' ', $classes);
}

/**
 * Process variables for node.tpl.php.
 */
function inkribbon_preprocess_node(&$vars) {
  // Provide useful classes.
  $classes = array(
    'node',
    'node-' . $vars['node']->type,
  );
  if ($vars['teaser']) {
    $classes[] = 'node-teaser';
  }
  if ($vars['sticky']) {
    $classes[] = 'node-sticky';
  }
  if (!$vars['status']) {
    $classes[] = 'node-unpublished';
  }
  $vars['classes'] = join(' ', $classes);
}

/**
 * Process variables for page.tpl.php.
 */
function inkribbon_preprocess_page(&$vars) {
  // Construct the logo. We use theme_image() to create the img so it gets
  // proper width and height attributes.
  if ($vars['logo']) {
    // Make the URL relative to base_path() so theme_image() can swallow it.
    $vars['logo'] = preg_replace('#^' . preg_quote(base_path()) . '#', '', $vars['logo']);

    $vars['logo'] = theme('image', $vars['logo'],
      t('!sitename logo', array(
        '!sitename' => $vars['site_name'],
      ))
    );
  }
}

/**
 * Return a themed form element.
 *
 * Overriden to remove the unnecessary colons from labels.
 */
function inkribbon_form_element($element, $value) {
  // This is also used in the installer, pre-database setup.
  $t = get_t();

  $output = '<div class="form-item"';
  if (!empty($element['#id'])) {
    $output .= ' id="' . $element['#id'] . '-wrapper"';
  }
  $output .= ">\n";

  // Construct the label.
  if (!empty($element['#title'])) {
    $title = $element['#title'];

    $required = '';
    if (!empty($element['#required'])) {
      $required = ' <span class="form-required" title="' . $t('This field is required.') . '">*</span>';
    }

    $attributes = '';
    if (!empty($element['#id'])) {
      $attributes = ' for="'. $element['#id'] .'"';
    }

    $output .= ' <label' . $attributes . '>' . filter_xss_admin($title) . $required . "</label>\n";
  }

  $output .= " $value\n";

  if (!empty($element['#description'])) {
    $output .= ' <div class="description">' . $element['#description'] . "</div>\n";
  }

  $output .= "</div>\n";

  return $output;
}

==> inkribbon-6.x-5.15.tar.gz: inkribbon/template.php <==
<?php
// $Id: template.php,v 1.38.2.3.2.3.2.24 2010/06/24 11:56:52 mverbaar Exp $

/**
 * Process variables for block.tpl.php.
 */
function inkribbon_preprocess_block(&$vars) {
  // Provide useful classes.
  $vars['classes'] = 'block block-' . $vars['block']->module;
}

/**
 * Process variables for comment.tpl.php.
 */
function inkribbon_preprocess_comment(&$vars) {
  // Provide useful classes.
  $classes = array(
    'comment',
    $status,
  );
  if ($vars['comment']->new) {
    $classes[] = 'comment-new';
  }
  $vars['classes'] = join(' ', $classes);
}

/**
 * Process variables for node.tpl.php.
 */
function inkribbon_preprocess_node(&$vars) {
  // Provide useful classes.
  $classes = array(
    'node',
    'node-' . $vars['node']->type,
  );
  if ($vars['teaser']) {
    $classes[] = 'node-teaser';
  }
  if ($vars['sticky']) {
    $classes[] = 'node-sticky';
  }
  if (!$vars['status']) {
    $classes[] = 'node-unpublished';
  }
  $vars['classes'] = join(' ', $classes);
}

/**
 * Process variables for page.tpl.php.
 */
function inkribbon_preprocess_page(&$vars) {
  // Construct the logo using theme_image() so it gets proper width and height attributes.
  if ($vars['logo']) {
    // Make the URL relative to base_path() so theme_image() can swallow it.
    $vars['logo'] = preg_replace('#^' . preg_quote(base_path()) . '#', '', $vars['logo']);

    $vars['logo'] = theme('image', $vars['logo'],
      t('!sitename logo', array(
        '!sitename' => $vars['site_name'],
      ))
    );
  }
}

/**
 * Return a themed form element.
 *
 * Overridden to remove the colons that are normally appended to form labels.
 */
function inkribbon_form_element($element, $value) {
  // This is also used in the installer, pre-database setup.
  $t = get_t();

  $output = '<div class="form-item"';
  if (!empty($element['#id'])) {
    $output .= ' id="' . $element['#id'] . '-wrapper"';
  }
  $output .= ">\n";

  // Construct the label.
  if (!empty($element['#title'])) {
    $title = $element['#title'];

    $required = '';
    if (!empty($element['#required'])) {
      $required = ' <span class="form-required" title="' . $t('This field is required.') . '">*</span>';
    }

    $attributes = '';
    if (!empty($element['#id'])) {
      $attributes = ' for="'. $element['#id'] .'"';
    }

    $output .= ' <label' . $attributes . '>' . filter_xss_admin($title) . $required . "</label>\n";
  }

  $output .= " $value\n";

  if (!empty($element['#description'])) {
    $output .= ' <div class="description">' . $element['#description'] . "</div>\n";
  }

  $output .= "</div>\n";

  return $output;
}
